@@ -58,8 +58,9 @@ def escapeMarkdown(text):
 			r.append("\\")
 		r.append(x)
 	text = ''.join(r)
-	for special_char in ['`', '*', 'https://', 'http://']:
+	for special_char in ['`', 'https://', 'http://']:
 		text = text.replace(special_char, '')
+	text = text.replace('*', '\\*') # may need to revisit
 	text = text.replace('t.cn/', ' t.cn/')
 	return compactText(text)
 
@@ -196,7 +197,7 @@ class TimedDeleter():
 			return tryDelete(msg)
 		delete_time = time.time() + minutes * 60
 		self.queue.append((delete_time, msg))
-		if len(self.queue) == 1
+		if len(self.queue) == 1:
 			self.schedule()
 
 	def schedule(self):
